@@ -20,26 +20,28 @@ DEFAULT_SETTINGS = {'padding': '0',
                     'url': '',
                     'less': False,
                     'optipng': False,
-                    'ignore_filename_paddings': True}
+                    'ignore_filename_paddings': True,
+                    'size': True,
+                    'png8': False}
 
 
 class MultipleImagesWithSameNameError(Exception):
-    """Raised if two images are going to have the same css class name."""
+    """Raised if two images pretend to generate the same CSS class name."""
     pass
 
 
 class SourceImagesNotFoundError(Exception):
-    """Raised if one folder doesn't contain any valid image."""
+    """Raised if a folder doesn't contain any valid image."""
     pass
 
 
 class NoSpritesFoldersFoundError(Exception):
-    """Raised if there is not any valid sprites folder."""
+    """Raised if no sprites folders could be found."""
     pass
 
 
 class InvalidImageOrderingAlgorithmError(Exception):
-    """Raised if the ordering algorithm is invalid."""
+    """Raised if the provided algorithm name is invalid."""
     pass
 
 
@@ -69,8 +71,8 @@ class Node(object):
         """Find a node to allocate this image size (width, height).
 
         :param node: Node to search in.
-        :param width: Amount of pixel to grow down (width).
-        :param height: Amount of pixel to grow down (height).
+        :param width: Pixels to grow down (width).
+        :param height: Pixels to grow down (height).
         """
         if node.used:
             return self.find(node.right, width, height) or \
@@ -80,10 +82,10 @@ class Node(object):
         return None
 
     def grow(self, width, height):
-        """ Grow the canvas to the more appropriate direction.
+        """ Grow the canvas to the most appropriate direction.
 
-        :param width: Amount of pixel to grow down (width).
-        :param height: Amount of pixel to grow down (height).
+        :param width: Pixels to grow down (width).
+        :param height: Pixels to grow down (height).
         """
         can_grow_d = width <= self.width
         can_grow_r = height <= self.height
@@ -105,8 +107,8 @@ class Node(object):
     def grow_right(self, width, height):
         """Grow the canvas to the right.
 
-        :param width: Amount of pixel to grow down (width).
-        :param height: Amount of pixel to grow down (height).
+        :param width: Pixels to grow down (width).
+        :param height: Pixels to grow down (height).
         """
         old_self = copy.copy(self)
         self.used = True
@@ -126,8 +128,8 @@ class Node(object):
     def grow_down(self, width, height):
         """Grow the canvas down.
 
-        :param width: Amount of pixel to grow down (width).
-        :param height: Amount of pixel to grow down (height).
+        :param width: Pixels to grow down (width).
+        :param height: Pixels to grow down (height).
         """
         old_self = copy.copy(self)
         self.used = True
@@ -147,7 +149,7 @@ class Node(object):
     def split(self, node, width, height):
         """Split the node to allocate a new one of this size.
 
-        :param node: Node to be splited.
+        :param node: Node to be splitted.
         :param width: New node width.
         :param height: New node height.
         """
@@ -168,7 +170,7 @@ class Image(object):
     ORDERINGS = ['maxside', 'width', 'height', 'area']
 
     def __init__(self, name, sprite):
-        """ Image constructor
+        """Image constructor
 
         :param name: Image name.
         :param sprite: :class:`~Sprite` instance for this image."""
@@ -182,7 +184,7 @@ class Image(object):
             self.image = PImage.open(image_file)
             self.image.load()
         except IOError, e:
-            sys.stderr.write(("ERROR: PIL %s decoder isn't available. "
+            sys.stderr.write(("ERROR: PIL %s decoder is unavailable. "
                               "Please read the documentation and "
                               "install it before spriting this kind of "
                               "images.\n" % e.args[0].split()[1]))
@@ -201,9 +203,9 @@ class Image(object):
 
     def _crop_image(self):
         """Crop the image searching for the smallest possible bounding box
-        without lossing any non-transparent pixel.
+        without losing any non-transparent pixel.
 
-        This crop is only used if the crop flag is present in the config.
+        This crop is only used if the crop flag is set in the config.
         """
         width, height = self.image.size
         maxx = maxy = 0
@@ -225,7 +227,7 @@ class Image(object):
         self.image = self.image.crop((minx, miny, maxx + 1, maxy + 1))
 
     def _generate_padding(self, padding):
-        """Return a four element list with the desired padding.
+        """Return a 4-elements list with the desired padding.
 
         :param padding: Padding as a list or a raw string representing
                         the padding for this image."""
@@ -239,25 +241,25 @@ class Image(object):
             padding = padding * 2
         elif len(padding) == 1:
             padding = padding * 4
-        elif len(padding) == 0:
-            padding = [self.DEFAULT_PADDING] * 4
+        else:
+            padding = [DEFAULT_SETTINGS['padding']] * 4
         return map(int, padding)
 
     @property
     def class_name(self):
-        """Return the css class name for this file.
+        """Return the CSS class name for this file.
 
-        This css class name will have the following format:
+        This CSS class name will have the following format:
 
         ``.[namespace]-[sprite_name]-[image_name]{ ... }``
 
-        The image_name will only contain the alphanumeric characters,
-        ``-`` and ``_``. The default namespace is ``sprite``, it but could
-        be overrided using the ``--namespace`` optional argument.
+        The image_name will only contain alphanumeric characters,
+        ``-`` and ``_``. The default namespace is ``sprite``, but it could
+        be overridden using the ``--namespace`` optional argument.
 
 
-        * ``animals/cat.png`` css class will be ``.sprite-animals-cat``
-        * ``animals/cow_20.png`` css class will be ``.sprite-animals-cow``
+        * ``animals/cat.png`` CSS class will be ``.sprite-animals-cat``
+        * ``animals/cow_20.png`` CSS class will be ``.sprite-animals-cow``
         """
         name = self.filename
         if not self.sprite.manager.config.ignore_filename_paddings:
@@ -265,12 +267,12 @@ class Image(object):
             if padding_info_name:
                 padding_info_name = '_%s' % padding_info_name
             name = name[:len(padding_info_name) * -1 or None]
-        name = re.sub(r'[^\w\-\_]', '', name)
+        name = re.sub(r'[^\w\-_]', '', name)
         return '%s-%s' % (self.sprite.namespace, name)
 
     @property
     def _padding_info(self):
-        """Return the padding information from the filename. """
+        """Return the padding information from the filename."""
         padding_info = self.filename.rsplit('_', 1)[-1]
         if re.match(r"^(\d+-?){,3}\d+$", padding_info):
             return padding_info.split('-')
@@ -279,12 +281,12 @@ class Image(object):
     @property
     def padding(self):
         """Return the padding for this image based on the filename and
-        sprite settings file preferences.
+        the sprite settings file.
 
         * ``filename.png`` will have the default padding ``10px``.
-        * ``filename_20.png`` -> ``20px`` all arround the image.
-        * ``filename_1-2-3.png`` -> ``1px 2px 3px 2px`` arround the image.
-        * ``filename_1-2-3-4.png`` -> ``1px 2px 3px 4px`` arround the image.
+        * ``filename_20.png`` -> ``20px`` all around the image.
+        * ``filename_1-2-3.png`` -> ``1px 2px 3px 2px`` around the image.
+        * ``filename_1-2-3-4.png`` -> ``1px 2px 3px 4px`` around the image.
 
         """
         padding = self._padding_info
@@ -304,7 +306,7 @@ class Image(object):
         return self.node.y + self.padding[0]
 
     def __lt__(self, img):
-        """Use the maxside, width, height or area as ordering algorithm.
+        """Use maxside, width, height or area as ordering algorithm.
 
         :param img: Another :class:`~Image`."""
         algorithm = self.sprite.config.algorithm
@@ -346,8 +348,8 @@ class Sprite(object):
         self.process()
 
     def process(self):
-        """Process a sprite path searchig for all the images and then
-        allocate all of them in the more appropriate position.
+        """Process a sprite path searching for all the images and then
+        allocate all of them in the most appropriate position.
         """
         self.images = self._locate_images()
         width = self.images[0].width
@@ -364,16 +366,16 @@ class Sprite(object):
                 image.node = root.grow(image.width, image.height)
 
     def _locate_images(self):
-        """Return all the valid images within a folder.
+        """Return all valid images within a folder.
 
-        All the files with an extension not included in VALID_IMAGE_EXTENSIONS
-        (png, jpg, jpeg and gif) or begging with a '.' will be ignored.
+        All files with a extension not included in VALID_IMAGE_EXTENSIONS
+        (png, jpg, jpeg and gif) or beginning with '.' will be ignored.
 
         If the folder doesn't contain any valid image it will raise
-        a :class:`~MultipleImagesWithSameNameError`
+        :class:`~MultipleImagesWithSameNameError`
 
         The list of images will be ordered using the desired ordering
-        algorithm. The default one is 'maxside'.
+        algorithm. The default is 'maxside'.
         """
         extensions = '|'.join(self.manager.VALID_IMAGE_EXTENSIONS)
         extension_re = re.compile('.+\.(%s)$' % extensions, re.IGNORECASE)
@@ -382,7 +384,7 @@ class Sprite(object):
                                     not n.startswith('.') and \
                                     extension_re.match(n)]
 
-        if len(images) == 0:
+        if not len(images):
             raise SourceImagesNotFoundError()
 
         # Check if there are duplicate class names
@@ -399,7 +401,7 @@ class Sprite(object):
 
         sprite_output_path = self.manager.output_path('img')
 
-        # Search for the max x and y (Neccesary to generate the canvas).
+        # Search for the max x and y (Necessary to generate the canvas).
         width = height = 0
 
         for image in self.images:
@@ -420,7 +422,23 @@ class Sprite(object):
         # Save png
         sprite_filename = '%s.png' % self.filename
         sprite_image_path = os.path.join(sprite_output_path, sprite_filename)
-        save = lambda: canvas.save(sprite_image_path, optimize=True)
+
+        args, kwargs = [sprite_image_path], dict(optimize=True)
+
+        if self.config.png8:
+            # Get the alpha band
+            alpha = canvas.split()[-1]
+            canvas = canvas.convert('RGB'
+                        ).convert('P', palette=PImage.ADAPTIVE, colors=255)
+
+            # Set all pixel values below 128 to 255, and the rest to 0
+            mask = PImage.eval(alpha, lambda a: 255 if a <= 128 else 0)
+
+            # Paste the color of index 255 and use alpha as a mask
+            canvas.paste(255, mask)
+            kwargs.update({'transparency': 255})
+
+        save = lambda: canvas.save(*args, **kwargs)
         save()
 
         if self.config.optipng:
@@ -430,33 +448,50 @@ class Sprite(object):
             error = subprocess.call(command, shell=True, stdin=subprocess.PIPE,
                             stdout=subprocess.PIPE)
             if error:
-                self.manager.log("Error: optipng has fail, reverting to "
+                self.manager.log("Error: optipng has failed, reverting to "
                                  "the original file.")
                 save()
 
     def save_css(self):
-        """Create the css or less file for this sprite."""
+        """Create the CSS or LESS file for this sprite."""
         format = 'less' if self.config.less else 'css'
         self.manager.log("Creating '%s' %s file..." % (self.name, format))
 
         output_path = self.manager.output_path('css')
-        css_filename = os.path.join(output_path, '%s.%s' % (self.filename,
-                                                            format))
+        filename = '%s.%s' % (self.filename, format)
+        css_filename = os.path.join(output_path, filename)
+
+        # Fix css urls on Windows
+        css_filename = '/'.join(css_filename.split('\\'))
+
         css_file = open(css_filename, 'w')
 
+        # get all the class names and join them
+        class_names = ['.%s' % i.class_name for i in self.images]
+        class_names = ',\n'.join(class_names)
+
+        # create an unique style for all the sprites for less bloat
+        style = "%s{background-image:url('%s');background-repeat:no-repeat;}\n"
+        css_file.write(style % (class_names, self.image_url))
+
         for image in self.images:
-            data = {'namespace': image.sprite.namespace,
-                    'sprite_url': image.sprite.image_url,
-                    'image_class_name': image.class_name,
+            data = {'image_class_name': image.class_name,
                     'top': image.node.y * -1 if image.node.y else 0,
                     'left': image.node.x * -1 if image.node.x else 0,
                     'width': image.width,
                     'height': image.height}
 
-            css_file.write((".%(image_class_name)s{ "
-                          "background:url('%(sprite_url)s') no-repeat "
-                          "%(left)ipx %(top)ipx;"
-                          "width:%(width)spx; height:%(height)spx;}\n") % data)
+            style = (".%(image_class_name)s{"
+                     "background-position:%(left)ipx %(top)ipx;")
+
+            if self.config.size:
+                # if it's required add the image size to the sprite
+                style += "width:%(width)spx; height:%(height)spx;"
+
+            style += "}\n"
+
+            css_file.write(style % data)
+
         css_file.close()
 
     @property
@@ -466,7 +501,7 @@ class Sprite(object):
 
     @property
     def filename(self):
-        """Return the desired filename for this sprite generated files."""
+        """Return the desired filename for files generated by this sprite."""
         return self.name
 
     @property
@@ -499,11 +534,11 @@ class ConfigManager(object):
         """ConfigManager constructor.
 
         :param *args: List of config dictionaries. The order of this list is
-                      important because as soon as one config property
+                      important because as soon as a config property
                       is available it will be returned.
         :param defaults: Dictionary with the default configuration.
         :param priority: Dictionary with the command line configuration. This
-                         configuration will overrida any other from any source.
+                         configuration will override any other from any source.
         """
         self.defaults = kwargs.get('defaults', {})
         self.priority = kwargs.get('priority', {})
@@ -520,8 +555,8 @@ class ConfigManager(object):
 
     def __getattr__(self, name):
         """Return the first available configuration value for this key. This
-        method always priorize the command line configuration. If this key
-        is not available within any configuration dictionary return the
+        method always prioritizes the command line configuration. If this key
+        is not available within any configuration dictionary, it returns the
         default value
 
         :param name: Configuration property name.
@@ -539,7 +574,7 @@ class BaseManager(object):
     VALID_IMAGE_EXTENSIONS = ['png', 'jpg', 'jpeg', 'gif']
 
     def __init__(self, path, config, output=None):
-        """ BaseManager constructor.
+        """BaseManager constructor.
 
         :param path: Sprite path.
         :param config: :class:`~ConfigManager` instance with all the
@@ -584,7 +619,7 @@ class BaseManager(object):
         return sprite_output_path
 
     def log(self, message):
-        """ Prints the message if it's necessary. """
+        """Print the message if necessary."""
         if not self.config.quiet:
             print(message)
 
@@ -595,33 +630,33 @@ class BaseManager(object):
 class MultipleSpriteManager(BaseManager):
 
     def process(self):
-        """Process a path searching for folders that contains images.
+        """Process a path searching for folders that contain images.
         Every folder will be a new sprite with all the images inside.
 
-        The filename of the image also can contain information about the
-        padding needed arround the image.
+        The filename of the image can also contain information about the
+        padding needed around the image.
 
-        * ``filename.png`` wil have the default padding (10px).
-        * ``filename_20.png`` will have 20px all arround the image.
-        * ``filename_1-2-3.png`` will have 1px 2px 3px 2px arround the image.
-        * ``filename_1-2-3-4.png`` will have 1px 2px 3px 4px arround the image.
+        * ``filename.png`` will have the default padding (10px).
+        * ``filename_20.png`` will have 20px all around the image.
+        * ``filename_1-2-3.png`` will have 1px 2px 3px 2px around the image.
+        * ``filename_1-2-3-4.png`` will have 1px 2px 3px 4px around the image.
 
-        The generated css file will have a css class for every image found
-        inside the sprite folder. This css class names will have the
+        The generated CSS file will have a CSS class for every image found
+        inside the sprites folder. These CSS class names will have the
         following format:
 
         ``.[namespace]-[sprite_name]-[image_name]{ ... }``
 
-        The image_name will only contain the alphanumeric characters,
-        ``-`` and ``_``. The default namespace is ``sprite``, it but could be
-        overrided using the ``--namespace`` optional argument.
+        The image_name will only contain alphanumeric characters,
+        ``-`` and ``_``. The default namespace is ``sprite``, but it could be
+        overridden using the ``--namespace`` optional argument.
 
 
-        * ``animals/cat.png`` css class will be ``.sprite-animals-cat``
-        * ``animals/cow_20.png`` css class will be ``.sprite-animals-cow``
+        * ``animals/cat.png`` CSS class will be ``.sprite-animals-cat``
+        * ``animals/cow_20.png`` CSS class will be ``.sprite-animals-cow``
 
-        If two images has the same name, a
-        :class:`~MultipleImagesWithSameNameError` error will be raised.
+        If two images have the same name,
+        :class:`~MultipleImagesWithSameNameError` will be raised.
         """
         for sprite_name in os.listdir(self.path):
             # Only process folders
@@ -629,7 +664,7 @@ class MultipleSpriteManager(BaseManager):
             if os.path.isdir(path):
                 self.process_sprite(path=path, name=sprite_name)
 
-        if len(self.sprites) == 0:
+        if not len(self.sprites):
             raise NoSpritesFoldersFoundError()
 
         self.save()
@@ -638,8 +673,8 @@ class MultipleSpriteManager(BaseManager):
 class SimpleSpriteManager(BaseManager):
 
     def process(self):
-        """Process an unique folder and create one sprite. It works in the
-        same way than :class:`~MultipleSpriteManager` but for only one folder.
+        """Process a single folder and create one sprite. It works the
+        same way as :class:`~MultipleSpriteManager`, but only for one folder.
 
         This is not the default manager. It is only used if you use
         the ``--simple`` default argument.
@@ -649,12 +684,14 @@ class SimpleSpriteManager(BaseManager):
 
 
 def get_file_config(path, section='sprite'):
-    """ Return as a dictionary all the available configuration inside the
-    sprite configuration file on this path
+    """Return, as a dictionary, all the available configuration inside the
+    sprite configuration file on this path.
 
     :param path: Path where the configuration file is.
-    :param section: The configuration file section que need to read.
+    :param section: The configuration file section that needs to be read.
     """
+    def clean(value):
+        return {'true': True, 'false': False}.get(value.lower(), value)
 
     config = ConfigParser.RawConfigParser()
     config.read(os.path.join(path, CONFIG_FILENAME))
@@ -662,11 +699,11 @@ def get_file_config(path, section='sprite'):
         keys = config.options(section)
     except ConfigParser.NoSectionError:
         return {}
-    return dict([[k, config.get(section, k)] for k in keys])
+    return dict([[k, clean(config.get(section, k))] for k in keys])
 
 
 def command_exists(command):
-    """ Check if a command exists running it.
+    """Check if a command exists by running it.
 
     :param command: command name.
     """
@@ -725,23 +762,25 @@ def main():
     parser = OptionParser(usage=("usage: %prog [options] source_dir [<output> "
                                  "| --css=<dir> --img=<dir>]"))
     parser.add_option("-s", "--simple", action="store_true", dest="simple",
-                      help="only generate sprites for one folder")
+                      help="generate sprites for a single folder")
     parser.add_option("-c", "--crop", dest="crop", action='store_true',
                 help="crop images removing unnecessary transparent margins")
     parser.add_option("-l", "--less", dest="less", action='store_true',
-                help="the output stylesheets will be .less and not .css")
+                help="generate output stylesheets as .less instead of .css")
     parser.add_option("-u", "--url", dest="url", default=None,
                       help="prepend this url to the sprites filename")
     parser.add_option("-q", "--quiet", dest="quiet", action='store_true',
                       help="suppress all normal output")
     parser.add_option("-p", "--padding", dest="padding", default=None,
-                      help="force this paddig to all the images")
+                      help="force this padding in all images")
+    parser.add_option("-z", "--no-size", action="store_false", dest="size",
+                      help="don't add the image size to the sprite")
 
     group = OptionGroup(parser, "Output Options")
     group.add_option("--css", dest="css_dir", default='',
-                    help="output directory for the css files", metavar='DIR')
+                    help="output directory for css files", metavar='DIR')
     group.add_option("--img", dest="img_dir", default='', metavar='DIR',
-                    help="output directory for the img files")
+                    help="output directory for img files")
     parser.add_option_group(group)
 
     group = OptionGroup(parser, "Advanced Options")
@@ -749,14 +788,17 @@ def main():
                     help=("ordering algorithm: maxside, width, height or "
                           "area (default: maxside)"), metavar='NAME')
     group.add_option("--namespace", dest="namespace",  default=None,
-                      help="namespace for the css (default: sprite)")
+                      help="namespace for all css classes (default: sprite)")
+    group.add_option("--png8", action="store_true", dest="png8",
+                      help=("the output image format will be png8 "
+                            "instead of png32"))
     group.add_option("--ignore-filename-paddings",
                       dest="ignore_filename_paddings", action='store_true',
                       help="ignore filename paddings")
     parser.add_option_group(group)
 
     group = OptionGroup(parser, "Optipng Options",
-                        "You must install optipng before using this options")
+                      "You need to install optipng before using these options")
     group.add_option("--optipng", dest="optipng", action='store_true',
                 help="postprocess images using optipng")
     group.add_option("--optipngpath", dest="optipngpath", default='optipng',
@@ -766,27 +808,27 @@ def main():
     group = OptionGroup(parser, "Browser Cache Invalidation Options")
     group.add_option("--cachebuster", dest="cachebuster",
                     action='store_true',
-                    help=("use the sprite's sha1 6 first characters as a "
-                          "queryarg everywhere that file is used on the "
-                          "css"))
+                    help=("use the sprite's first 6 sha1 characters as a "
+                          "queryarg everytime that file is referred from "
+                          "the css"))
     parser.add_option_group(group)
 
     (options, args) = parser.parse_args()
 
-    if len(args) == 0:
-        parser.error("You must choose the folder that contains the sprites.")
+    if not len(args):
+        parser.error("You must provide the folder containing the sprites.")
 
     if len(args) == 1 and not (options.css_dir and options.img_dir):
-        parser.error(("You must choose the output folder using the output "
-                      "argument or --img and --css."))
+        parser.error(("You must choose the output folder using either the "
+                      "output argument or both --img and --css."))
 
     if len(args) == 2 and (options.css_dir or options.img_dir):
         parser.error(("You must choose between using an unique output dir, or "
                       "using --css and --img."))
 
     if options.optipng and not command_exists(options.optipngpath):
-        parser.error("'optipng' seems to not be available. You must "
-                     "install it before using the --optipng option or "
+        parser.error("'optipng' seems to be unavailable. You need to "
+                     "install it before using --optipng, or "
                      "provide a path using --optipngpath.")
 
     source = os.path.abspath(args[0])
@@ -815,9 +857,9 @@ def main():
         sys.stderr.write("Error: Some images will have the same class name:\n")
         for image in e.args[0]:
             sys.stderr.write('\t %s => .%s\n' % (image.name, image.class_name))
-    except SourceImagesNotFoundError, e:
+    except SourceImagesNotFoundError:
         sys.stderr.write("Error: No images found.\n")
-    except NoSpritesFoldersFoundError, e:
+    except NoSpritesFoldersFoundError:
         sys.stderr.write("Error: No sprites folders found.\n")
 
 
